Introduction
============

When you install the `anemoi-inference` package, this will also install command line tool
called ``anemoi-inference`` this can be used to manage the checkpoints.

The tools can provide help with the ``--help`` options:

.. code-block:: bash

    % anemoi-inference --help


The commands are:

- :ref:`Run Command <run_command>`
- :ref:`Metadata Command <metadata_command>`
- :ref:`Inspect Command <inspect_command>`
- :ref:`Validate Command <validate_command>`
- :ref:`Patch Command <patch_command>`
- :ref:`Requests Command <requests_command>`
